"use client";

import React, { useEffect, useState } from 'react';
import { FaStar } from 'react-icons/fa';
import Link from 'next/link';

const LatestGrid: React.FC = () => {
  const [activeTab, setActiveTab] = useState<'movie' | 'tv'>('movie');
  const [items, setItems] = useState<any[]>([]);
  const [itemsToShow, setItemsToShow] = useState(40);
  const [fadeKey, setFadeKey] = useState(0);

  useEffect(() => {
    const calculateItemsToShow = () => {
      const screenWidth = window.innerWidth;
      if (screenWidth >= 1024) {
        setItemsToShow(40); // 40 items for PC
      } else {
        setItemsToShow(21); // 21 items for mobile
      }
    };

    calculateItemsToShow();
    window.addEventListener('resize', calculateItemsToShow);

    return () => {
      window.removeEventListener('resize', calculateItemsToShow);
    };
  }, []);

  useEffect(() => {
    const fetchItems = async () => {
      const type = activeTab === 'movie' ? 'movie' : 'tv';
      try {
        const response = await fetch(
          `https://api.themoviedb.org/3/trending/${type}/day?api_key=${process.env.NEXT_PUBLIC_TMDB_API_KEY}`
        );
        const data = await response.json();
        
        let allItems = [...data.results];
        if (allItems.length < itemsToShow) {
          const nextPageResponse = await fetch(
            `https://api.themoviedb.org/3/trending/${type}/day?api_key=${process.env.NEXT_PUBLIC_TMDB_API_KEY}&page=2`
          );
          const nextPageData = await nextPageResponse.json();
          allItems = [...allItems, ...nextPageData.results];
        }
        
        setItems(allItems.slice(0, itemsToShow));
      } catch (error) {
        console.error(`Failed to fetch trending ${type} data:`, error);
      }
    };

    fetchItems();
    setFadeKey((prevKey) => prevKey + 1);

  }, [activeTab, itemsToShow]);

  return (
    <div className="relative mt-12">
      <div className="flex justify-start items-center mb-6 pl-4">
        <h2 className="text-white text-2xl mr-4 font-orbitron">Latest</h2>
        <div
          className="relative inline-block w-36 h-10 bg-gray-200 rounded-full cursor-pointer"
          onClick={() => setActiveTab(activeTab === 'movie' ? 'tv' : 'movie')}
        >
          <div
            className={`absolute top-0.5 bottom-0.5 left-0.5 w-[50%] h-9 rounded-full bg-red-600 transition-transform duration-500 ease-in-out ${
              activeTab === 'tv' ? 'translate-x-full' : ''
            }`}
          ></div>
          <div className="absolute inset-0 flex justify-between items-center px-4">
            <span className={`text-sm font-orbitron ${activeTab === 'movie' ? 'text-white' : 'text-gray-600'}`}>
              Movie
            </span>
            <span className={`text-sm font-orbitron ${activeTab === 'tv' ? 'text-white' : 'text-gray-600'}`}>
              TV   
              </span>
          </div>
        </div>
      </div>

      <div key={fadeKey} className="grid grid-cols-3 sm:grid-cols-3 md:grid-cols-5 lg:grid-cols-8 gap-4 px-4 animate-fadeIn">
        {items.map((item) => {
          const slug = `${item.id}-${item.name || item.title}`.toLowerCase().replace(/ /g, '-');
          const url = activeTab === 'movie' ? `/watch/movie/?slug=${slug}` : `/watch/tv/?slug=${slug}`;

          return (
            <Link key={item.id} href={url} passHref>
              <div
                className="relative bg-cover bg-center rounded-lg overflow-hidden shadow-lg hover:scale-105 transition-transform duration-300 ease-in-out cursor-pointer"
                style={{
                  backgroundImage: `url(https://image.tmdb.org/t/p/w500${item.poster_path})`,
                  paddingBottom: '150%', 
                }}
              >
                <div className="absolute top-2 right-2 bg-black bg-opacity-70 text-yellow-400 text-xs px-2 py-1 rounded flex items-center">
                  <FaStar className="mr-1" />
                  {item.vote_average.toFixed(1)}
                </div>
              </div>
            </Link>
          );
        })}
      </div>

      {/* Spacer for Mobile Navbar */}
      <div className="md:hidden h-24"></div>
      {/* Spacer for PC */}
      <div className="hidden md:block h-12"></div>
    </div>
  );
};

export default LatestGrid;
